Citing NIFTy and the Magic Inside
=================================

To cite the software library NIFTy, please use the following references:

.. parsed-literal::
    @article{niftyre,
      title         = {Re-Envisioning Numerical Information Field Theory (NIFTy.re): A Library for Gaussian Processes and Variational Inference},
      author        = {Gordian Edenhofer and Philipp Frank and Jakob Roth and Reimar H. Leike and Massin Guerdi and Lukas I. Scheel-Platz and Matteo Guardiani and Vincent Eberle and Margret Westerkamp and Torsten A. Enßlin},
      year          = {2024},
      journal       = {Journal of Open Source Software},
      publisher     = {The Open Journal},
      volume        = {9},
      number        = {98},
      pages         = {6593},
      doi           = {10.21105/joss.06593},
      url           = {https://doi.org/10.21105/joss.06593},
    }
    @article{nifty5,
      author        = {{Arras}, Philipp and {Baltac}, Mihai and {Ensslin}, Torsten A. and {Frank}, Philipp and {Hutschenreuter}, Sebastian and {Knollmueller}, Jakob and {Leike}, Reimar and {Newrzella}, Max-Niklas and {Platz}, Lukas and {Reinecke}, Martin and {Stadler}, Julia},
      title         = {{NIFTy5: Numerical Information Field Theory v5}},
      keywords      = {Software},
      howpublished  = {Astrophysics Source Code Library, record ascl:1903.008},
      year          = 2019,
      month         = 03,
      eid           = {ascl:1903.008},
      pages         = {ascl:1903.008},
      archiveprefix = {ascl},
      eprint        = {1903.008}
    }
    @article{nifty3,
      author        = {{Steininger}, Theo and {Dixit}, Jait and {Frank}, Philipp and {Greiner}, Maksim and {Hutschenreuter}, Sebastian and {Knollm{\"u}ller}, Jakob and {Leike}, Reimar and {Porqueres}, Natalia and {Pumpe}, Daniel and {Reinecke}, Martin and {{\v{S}}raml}, Matev{\v{z}} and {Varady}, Csongor and {En{\ss}lin}, Torsten},
      title         = "{NIFTy 3 - Numerical Information Field Theory: A Python Framework for Multicomponent Signal Inference on HPC Clusters}",
      journal       = {{Annalen der Physik}},
      year          = 2019,
      month         = {03},
      volume        = {531},
      number        = {3},
      pages         = {1800290},
      doi           = {10.1002/andp.201800290},
    }
    @article{nifty1,
      author        = {{Selig}, M. and {Bell}, M.~R. and {Junklewitz}, H. and {Oppermann}, N. and {Reinecke}, M. and {Greiner}, M. and {Pachajoa}, C. and {En{\ss}lin}, T.~A.},
      title         = "{NIFTY - Numerical Information Field Theory. A versatile PYTHON library for signal inference}",
      journal       = {Astronomy \& Astrophysics},
      archivePrefix = "arXiv",
      eprint        = {1301.4499},
      primaryClass  = "astro-ph.IM",
      keywords      = {methods: data analysis, methods: numerical, methods: statistical, techniques: image processing},
      year          = 2013,
      month         = {06},
      volume        = 554,
      eid           = {A26},
      pages         = {A26},
      doi           = {10.1051/0004-6361/201321236},
    }

For the inference machinery, please cite:

.. parsed-literal::
    @article{Frank2021,
      author         = {Frank, Philipp and Leike, Reimar and Enßlin, Torsten A.},
      title          = {Geometric Variational Inference},
      journal        = {Entropy},
      volume         = {23},
      year           = {2021},
      number         = {7},
      article-number = {853},
      url            = {https://www.mdpi.com/1099-4300/23/7/853},
      issn           = {1099-4300},
      doi            = {10.3390/e23070853}
    }
    @misc{knollmüller2020metric,
      title          = {Metric Gaussian Variational Inference},
      author         = {Jakob Knollmüller and Torsten A. Enßlin},
      year           = {2020},
      eprint         = {1901.11033},
      archivePrefix  = {arXiv},
      primaryClass   = {stat.ML}
    }

If you use the correlated field model from NIFTy, please additionally cite:

.. parsed-literal::
    @article{Arras2022,
      author         = {{Arras}, Philipp and {Frank}, Philipp and {Haim}, Philipp and {Knollm{\"u}ller}, Jakob and {Leike}, Reimar and {Reinecke}, Martin and {En{\ss}lin}, Torsten},
      title          = "{Variable structures in M87* from space, time and frequency resolved interferometry}",
      journal        = {Nature Astronomy},
      year           = 2022,
      month          = jan,
      volume         = {6},
      pages          = {259-269},
      doi            = {10.1038/s41550-021-01548-0},
    }
    @article{Arras2021,
      author         = {{Arras}, Philipp and {Bester}, Hertzog L. and {Perley}, Richard A. and {Leike}, Reimar and {Smirnov}, Oleg and {Westermann}, R{\"u}diger and {En{\ss}lin}, Torsten A.},
      title          = "{Comparison of classical and Bayesian imaging in radio interferometry. Cygnus A with CLEAN and resolve}",
      journal        = {Astronomy and Astrophysics},
      year           = 2021,
      month          = feb,
      volume         = {646},
      eid            = {A84},
      pages          = {A84},
      doi            = {10.1051/0004-6361/202039258},
    }

For the charted refinement model, please cite:

.. parsed-literal::
    @misc{Edenhofer2022,
      doi       = {10.48550/ARXIV.2206.10634},
      url       = {https://arxiv.org/abs/2206.10634},
      author    = {Edenhofer, Gordian and Leike, Reimar H. and Frank, Philipp and Enßlin, Torsten A.},
      keywords  = {Machine Learning (cs.LG), Machine Learning (stat.ML), FOS: Computer and information sciences, FOS: Computer and information sciences},
      title     = {Sparse Kernel Gaussian Processes through Iterative Charted Refinement (ICR)},
      publisher = {arXiv},
      year      = {2022},
    }
